@@ -621,6 +621,61 @@ class OrcaTests(InputTests):
 
         self.assertTrue(self.is_equivalent(REF, inp.input_file))
 
+    def test_sp_DLPNO_CCSDT_default_aux_specifications(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "DLPNO-CCSD(T)",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "specifications": "tightscf",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP DLPNO-CCSD(T) cc-pVTZ cc-pVTZ/C tightscf
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %MaxCore 125
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_sp_DLPNO_CCSDT_default_aux_solvation(self):
+        params = {
+            "nproc": 8,
+            "type": "Single-Point Energy",
+            "file": "Cl.xyz",
+            "software": "ORCA",
+            "method": "DLPNO-CCSD(T)",
+            "basis_set": "cc-pVTZ",
+            "charge": "-1",
+            "solvent": "ch2cl2",
+            "solvation_model": "CPCM",
+        }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        !SP DLPNO-CCSD(T) cc-pVTZ cc-pVTZ/C CPCM(ch2cl2)
+        *xyz -1 1
+        Cl 0.0 0.0 0.0
+        *
+        %MaxCore 125
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
     def test_sp_CCSDT(self):
         params = {
             "nproc": 8,
@@ -1264,26 +1319,7 @@ class OrcaTests(InputTests):
         Calc_Hess true
         end
         %basis
-        newgto N
-        S   5
-        1      1712.8415853             -0.53934125305E-02
-        2       257.64812677            -0.40221581118E-01
-        3        58.458245853           -0.17931144990
-        4        16.198367905           -0.46376317823
-        5         5.0052600809          -0.44171422662
-        S   1
-        1         0.58731856571          1.0000000
-        S   1
-        1         0.18764592253          1.0000000
-        P   3
-        1        13.571470233           -0.40072398852E-01
-        2         2.9257372874          -0.21807045028
-        3         0.79927750754         -0.51294466049
-        P   1
-        1         0.21954348034          1.0000000
-        D   1
-        1         1.0000000              1.0000000
-        end
+        NewGTO N "Def2-SVP" end
         end
         %MaxCore 125
         %pal
@@ -1319,26 +1355,7 @@ class OrcaTests(InputTests):
         Calc_Hess true
         end
         %basis
-        newgto N
-        S   5
-        1      1712.8415853             -0.53934125305E-02
-        2       257.64812677            -0.40221581118E-01
-        3        58.458245853           -0.17931144990
-        4        16.198367905           -0.46376317823
-        5         5.0052600809          -0.44171422662
-        S   1
-        1         0.58731856571          1.0000000
-        S   1
-        1         0.18764592253          1.0000000
-        P   3
-        1        13.571470233           -0.40072398852E-01
-        2         2.9257372874          -0.21807045028
-        3         0.79927750754         -0.51294466049
-        P   1
-        1         0.21954348034          1.0000000
-        D   1
-        1         1.0000000              1.0000000
-        end
+        NewGTO N "Def2-SVP" end
         end
         %MaxCore 125
         %pal
@@ -1390,100 +1407,8 @@ class OrcaTests(InputTests):
         H         -5.61500        4.53870       -5.19320
         *
         %basis
-        newgto I
-        S   5
-        1      5899.5791533              0.24188269271E-03
-        2       898.54238765             0.15474041742E-02
-        3       200.37237912             0.42836684457E-02
-        4        31.418053840           -0.39417936275E-01
-        5        15.645987838            0.96086691992
-        S   2
-        1        11.815741857            0.75961524091
-        2         6.4614458287           0.42495501835
-        S   1
-        1         2.3838067579           1.0000000
-        S   1
-        1         1.1712089662           1.0000000
-        S   1
-        1         0.32115875757          1.0000000
-        S   1
-        1         0.12387919364          1.0000000
-        S   1
-        1         0.43491550641E-01      1.0000000
-        P   3
-        1       197.30030547             0.73951226905E-03
-        2        20.061411349            0.66168450008E-01
-        3         9.7631460485          -0.28554662348
-        P   4
-        1        12.984316904           -0.49096186164E-01
-        2         3.6199503008           0.38914432482
-        3         2.0232273090           0.65610817262
-        4         1.0367490559           0.31803551647
-        P   1
-        1         0.45937816000          1.0000000
-        P   1
-        1         0.19116532928          1.0000000
-        P   1
-        1         0.74878813023E-01      1.0000000
-        P   1
-        1         0.21653491846E-01      1.0000000
-        D   6
-        1       119.12671745             0.82596039573E-03
-        2        33.404240134            0.68377675770E-02
-        3        17.805918203           -0.10308158997E-01
-        4         4.8990510353           0.22670457658
-        5         2.4516753106           0.44180113937
-        6         1.1820693432           0.36775472225
-        D   1
-        1         0.52923110068          1.0000000
-        D   1
-        1         0.17000000000          1.0000000
-        D   1
-        1         0.61341708807E-01      1.0000000
-        F   1
-        1         2.1800000              1.0000000
-        F   1
-        1         0.44141808             1.0000000
-        end
-
-        NewECP I
-          N_core 28
-          lmax f
-          s 7
-           1     40.01583500    49.99429300 2
-           2     17.42974700   281.02531700 2
-           3      9.00548400    61.57332600 2
-           4     19.45860900    21.84204000 2
-           5     19.34926000    28.46819100 2
-           6      4.82376700     0.24371300 2
-           7      4.88431500     0.32080400 2
-          p 8
-           1     15.35546600    67.44284100 2
-           2     14.97183300   134.88113700 2
-           3      8.96016400    14.67505100 2
-           4      8.25909600    29.37566600 2
-           5     19.45860900    21.84204000 2
-           6     19.34926000    28.46819100 2
-           7      4.82376700     0.24371300 2
-           8      4.88431500     0.32080400 2
-          d 10
-           1     15.06890800    35.43952900 2
-           2     14.55532200    53.17605700 2
-           3      6.71864700     9.06719500 2
-           4      6.45639300    13.20693700 2
-           5      1.19177900     0.08933500 2
-           6      1.29115700     0.05238000 2
-           7     19.45860900    21.84204000 2
-           8     19.34926000    28.46819100 2
-           9      4.82376700     0.24371300 2
-           10     4.88431500     0.32080400 2
-          f 4
-           1     19.45860900   -21.84204000 2
-           2     19.34926000   -28.46819100 2
-           3      4.82376700    -0.24371300 2
-           4      4.88431500    -0.32080400 2
-        end
-
+        NewGTO I "Def2-TZVPD" end
+        NewECP I "def2-ECP" end
         end
         %MaxCore 125
         %pal
@@ -1507,6 +1432,59 @@ class OrcaTests(InputTests):
 
         inp = self.generate_calculation(**params)
 
+        REF = """
+        !OPT B3LYP 6-31+G(d,p)
+        *xyz 1 1
+        C         -3.06870       -2.28540        0.00000
+        C         -1.67350       -2.28540        0.00000
+        C         -0.97600       -1.07770        0.00000
+        C         -1.67360        0.13090       -0.00120
+        C         -3.06850        0.13080       -0.00170
+        C         -3.76610       -1.07740       -0.00070
+        H         -3.61840       -3.23770        0.00040
+        H         -1.12400       -3.23790        0.00130
+        H          0.12370       -1.07760        0.00060
+        H         -1.12340        1.08300       -0.00130
+        H         -4.86570       -1.07720       -0.00090
+        I         -4.11890        1.94920       -0.00350
+        C         -4.64360        2.85690       -1.82310
+        C         -3.77180        3.76300       -2.42740
+        C         -5.86360        2.55380       -2.42750
+        C         -4.12020        4.36650       -3.63560
+        H         -2.81040        4.00240       -1.95030
+        C         -6.21180        3.15650       -3.63650
+        H         -6.55070        1.83950       -1.95140
+        C         -5.34050        4.06290       -4.24060
+        H         -3.43340        5.08120       -4.11170
+        H         -7.17360        2.91710       -4.11310
+        H         -5.61500        4.53870       -5.19320
+        *
+        %basis
+        NewGTO I "Def2-TZVPD" end
+        NewECP I "def2-ECP" end
+        end
+        %MaxCore 125
+        %pal
+        nprocs 8
+        end
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_opt_DFT_custom_bs_explicit(self):
+        params = {
+            "nproc": 8,
+            "type": "Geometrical Optimisation",
+            "file": "Ph2I_cation.xyz",
+            "software": "ORCA",
+            "charge": "+1",
+            "method": "B3LYP",
+            "basis_set": "6-31+G(d,p)",
+            "custom_basis_sets": "I=psbkjc;",
+        }
+
+        inp = self.generate_calculation(**params)
+
         REF = """
         !OPT B3LYP 6-31+G(d,p)
         *xyz 1 1
@@ -1536,99 +1514,54 @@ class OrcaTests(InputTests):
         *
         %basis
         newgto I
-        S   5
-        1      5899.5791533              0.24188269271E-03
-        2       898.54238765             0.15474041742E-02
-        3       200.37237912             0.42836684457E-02
-        4        31.418053840           -0.39417936275E-01
-        5        15.645987838            0.96086691992
+        S   4
+        1         2.6250000              0.07366000
+        2         1.0140000             -0.83687000
+        3         0.5009000              0.65624700
+        4         0.2023000              0.90074400
         S   2
-        1        11.815741857            0.75961524091
-        2         6.4614458287           0.42495501835
-        S   1
-        1         2.3838067579           1.0000000
-        S   1
-        1         1.1712089662           1.0000000
-        S   1
-        1         0.32115875757          1.0000000
-        S   1
-        1         0.12387919364          1.0000000
-        S   1
-        1         0.43491550641E-01      1.0000000
-        P   3
-        1       197.30030547             0.73951226905E-03
-        2        20.061411349            0.66168450008E-01
-        3         9.7631460485          -0.28554662348
+        1         0.2023000              1.00000000
+        2         0.0780000              1.00000000
+        S   2
+        1         0.0780000              1.00000000
+        2         0.0300741              1.00000000
         P   4
-        1        12.984316904           -0.49096186164E-01
-        2         3.6199503008           0.38914432482
-        3         2.0232273090           0.65610817262
-        4         1.0367490559           0.31803551647
-        P   1
-        1         0.45937816000          1.0000000
-        P   1
-        1         0.19116532928          1.0000000
-        P   1
-        1         0.74878813023E-01      1.0000000
-        P   1
-        1         0.21653491846E-01      1.0000000
-        D   6
-        1       119.12671745             0.82596039573E-03
-        2        33.404240134            0.68377675770E-02
-        3        17.805918203           -0.10308158997E-01
-        4         4.8990510353           0.22670457658
-        5         2.4516753106           0.44180113937
-        6         1.1820693432           0.36775472225
-        D   1
-        1         0.52923110068          1.0000000
-        D   1
-        1         0.17000000000          1.0000000
-        D   1
-        1         0.61341708807E-01      1.0000000
-        F   1
-        1         2.1800000              1.0000000
-        F   1
-        1         0.44141808             1.0000000
+        1         2.6250000             -0.00888000
+        2         1.0140000             -0.25735100
+        3         0.5009000              0.45536800
+        4         0.2023000              0.76010700
+        P   2
+        1         0.2023000              1.00000000
+        2         0.0780000              1.00000000
+        P   2
+        1         0.0780000              1.00000000
+        2         0.0300741              1.00000000
+        D   2
+        1         0.5009000              0.36111300
+        2         0.2023000              0.93252210
+        D   2
+        1         0.0780000              0.93733150
+        2         0.0300741              0.34843880
         end
 
         NewECP I
-          N_core 28
-          lmax f
-          s 7
-           1     40.01583500    49.99429300 2
-           2     17.42974700   281.02531700 2
-           3      9.00548400    61.57332600 2
-           4     19.45860900    21.84204000 2
-           5     19.34926000    28.46819100 2
-           6      4.82376700     0.24371300 2
-           7      4.88431500     0.32080400 2
-          p 8
-           1     15.35546600    67.44284100 2
-           2     14.97183300   134.88113700 2
-           3      8.96016400    14.67505100 2
-           4      8.25909600    29.37566600 2
-           5     19.45860900    21.84204000 2
-           6     19.34926000    28.46819100 2
-           7      4.82376700     0.24371300 2
-           8      4.88431500     0.32080400 2
-          d 10
-           1     15.06890800    35.43952900 2
-           2     14.55532200    53.17605700 2
-           3      6.71864700     9.06719500 2
-           4      6.45639300    13.20693700 2
-           5      1.19177900     0.08933500 2
-           6      1.29115700     0.05238000 2
-           7     19.45860900    21.84204000 2
-           8     19.34926000    28.46819100 2
-           9      4.82376700     0.24371300 2
-           10     4.88431500     0.32080400 2
-          f 4
-           1     19.45860900   -21.84204000 2
-           2     19.34926000   -28.46819100 2
-           3      4.82376700    -0.24371300 2
-           4      4.88431500    -0.32080400 2
+        N_core 46
+        lmax f
+        s 3
+        1      4.1307100     12.1112300 0
+        2      1.3337500    -41.0920600 2
+        3      1.4912100     70.7376100 2
+        p 3
+        1      3.0469200     10.5927100 0
+        2      1.0633900    -46.0227300 2
+        3      1.1440500     65.0504700 2
+        d 2
+        1      3.9306300      9.7308900 0
+        2      1.0692000     13.9888000 2
+        f 2
+        1      0.9762800     -3.6963900 1
+        2      4.3334300    -14.0030500 1
         end
-
         end
         %MaxCore 125
         %pal
